==> md5-node-cg-lib-0.0.1.tgz: package/README.md <==
[![N|Solid](https://camo.githubusercontent.com/7abb57293f5008cb92245355118af529419d49d45195e01d1d33051b6ef3204b/68747470733a2f2f636c6f756467656e7379732e636f6d2f63672d64656d6f2f77702d636f6e74656e742f75706c6f6164732f323031392f30352f43472d4c6f676f2d30312e706e67)](https://nodesource.com/products/nsolid)
# md5-node-cg-lib
The library can be downloaded from the following url:
https://github.com/CloudGenUser/md5-node-cg-lib.git
The downloaded  must be Imported to the Project that is intended to be used
## 1. Introduction

This library allows generating an MD5 ID that can be used to identify and ensure if two objects are the same. With this validation the user can be sure of the integrity of the information that flows.

## 2. Library usage

The library can be installed from "missing location"

### 2.1 Library Methods
#### Method getMd5ID
This method creates the "crypto" module that provides cryptographic functionality that includes a set of
 wrappers for OpenSSL hashing, HMAC, recording, decryption, signing, and verification functions.
 The algorithm depends on the available algorithms supported by the version of OpenSSL on the platform.
 Compute the digest of all passed data to be encrypted (using the hash.update() method)

## 3. Example
1. VALIDATE OBJECTS

Validate the objects are correct

2. GET LOCATION OF OBJECT

Get the path of Object 

3. RUN THE APP MD5

Run the app in development IDE.
      
4. VALIDATE THE RUN IN THE LOG
Validates in the log if the object was transformed through a message in the console where it shows the encryption of the String.

```node
const getMd5ID =  (content) => {
    try {
        return crypto.createHash('md5').update(content).digest("hex");
    } catch (error) {
        log.error(`Error Creating MD5 id: ${error}`);
        throw Error(error);
    }
}
```
The Result is: 
``` 
Result MD5 id: d501194c987486789bb01b50dc1a0adb
```

==> md5-node-cg-lib-0.0.6.tgz: package/README.md <==
[![N|Solid](https://camo.githubusercontent.com/7abb57293f5008cb92245355118af529419d49d45195e01d1d33051b6ef3204b/68747470733a2f2f636c6f756467656e7379732e636f6d2f63672d64656d6f2f77702d636f6e74656e742f75706c6f6164732f323031392f30352f43472d4c6f676f2d30312e706e67)](https://nodesource.com/products/nsolid)
# md5-node-cg-lib
The library can be downloaded from the following url:
https://github.com/CloudGenUser/md5-node-cg-lib.git
The downloaded  must be Imported to the Project that is intended to be used
## 1. Introduction

This library allows generating an MD5 ID that can be used to identify and ensure if two objects are the same. With this validation the user can be sure of the integrity of the information that flows.

## 2. Library usage

The library can be installed from npm page with the next:
````
npm install md5-node-cg-lib, npm i md5-node-cg-lib or yarn install md5-node-cg-lib
````
### 2.1 Library Methods
#### Method getMd5ID
This method creates the "crypto" module that provides cryptographic functionality that includes a set of
 wrappers for OpenSSL hashing, HMAC, recording, decryption, signing, and verification functions.
 The algorithm depends on the available algorithms supported by the version of OpenSSL on the platform.
 Compute the digest of all passed data to be encrypted (using the hash.update() method)

## 3. Example
1. VALIDATE OBJECTS

Validate the objects are correct

2. GET LOCATION OF OBJECT

Get the path of Object 

3. RUN THE APP MD5

Run the app in development IDE.
      
4. VALIDATE THE RUN IN THE LOG
Validates in the log if the object was transformed through a message in the console where it shows the encryption of the String.

```node
const getMd5ID = (content) => {
    try {
        return crypto.createHash('md5').update(content).digest("hex");
    } catch (error) {
        log.error(`Error Creating MD5 id: ${error}`);
        throw Error(error);
    }
}

```
The Result is: 
``` 
Result MD5 id: d501194c987486789bb01b50dc1a0adb

```
